@@ -86,7 +86,7 @@ class PowerLoopPoint(widget.OWWidget):
 
     name = "Power Density Loop Point"
     description = "Tools: LoopPoint"
-    icon = "icons/cycle.png"
+    icon = "icons/cycle_power.png"
     maintainer = "Luca Rebuffi"
     maintainer_email = "lrebuffi(@at@)anl.gov"
     priority = 5
